# Generated by Django 3.2.16 on 2024-07-24 03:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptionmanager', '0010_auto_20240623_2142'),
    ]

    operations = [
        migrations.AddField(
            model_name='subscriptionsummary',
            name='customer_address',
            field=models.CharField(default='', max_length=1000),
            preserve_default=False,
        ),
    ]
